ReadyBottomBar class

Inheritance

Constructors

ReadyBottomBar({Key? key, Widget? child, List<Widget>? children, EdgeInsetsGeometry padding = const EdgeInsets.all(16.0), Color? backgroundColor, bool showTopBorder = false, Color? borderColor, double borderWidth = 1.0, BorderRadiusGeometry? borderRadius, double elevation = 0.0})
const

Properties

backgroundColor Color?
Background color of the bottom bar.
final
borderColor Color?
Color of the top border (if visible).
final
borderRadius BorderRadiusGeometry?
Border radius around the container.
final
borderWidth double
Width of the top border.
final
child Widget?
A single widget to show inside the bottom bar.
final
children List<Widget>?
Multiple widgets to show inside the bottom bar.
final
elevation double
Elevation for shadow effect.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
padding EdgeInsetsGeometry
Padding around the content.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showTopBorder bool
Whether to display a top border.
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited