buttons/ready_buttons library

Classes

ReadyElevatedButton
Position of the icon in the ReadyElevatedButton A customizable elevated button with optional icon and styles
ReadyIconButton
ReadyLikeButton
ReadyTextButton
Enum to define button size A flexible, customizable text button for various use cases.

Enums

ButtonStyleType
IconPosition
Defines the position of an icon in a button
ReadyButtonSize