ReadyLikeButton class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- ReadyLikeButton
Constructors
-
ReadyLikeButton({Key? key, Future<
bool?> onTap(bool isLiked)?, double iconSize = 26, Color? iconColor, IconData solidIcon = Icons.favorite, IconData outlineIcon = Icons.favorite_border, bool isLiked = false, Color? borderColor, double borderRadius = 8, double borderWidth = 1, ReadyButtonSize size = ReadyButtonSize.medium}) -
Default transparent button with outline style
factory
-
ReadyLikeButton.outlined({Key? key, Future<
bool?> onTap(bool isLiked)?, double iconSize = 26, Color? color, Color? iconColor, IconData solidIcon = Icons.favorite, IconData outlineIcon = Icons.favorite_border, bool isLiked = false, Color? borderColor, double borderRadius = 8, double borderWidth = 1, ReadyButtonSize size = ReadyButtonSize.medium}) -
const
-
ReadyLikeButton.solid({Key? key, Future<
bool?> onTap(bool isLiked)?, double iconSize = 26, Color? color, Color? iconColor, IconData solidIcon = Icons.favorite, IconData outlineIcon = Icons.favorite_border, bool isLiked = false, Color? borderColor, double borderRadius = 8, double borderWidth = 1, ReadyButtonSize size = ReadyButtonSize.medium}) -
const
Properties
- borderColor → Color?
-
final
- borderRadius → double
-
final
- borderWidth → double
-
final
- color → Color?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- iconColor → Color?
-
final
- iconSize → double
-
final
- isLiked → bool
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
-
onTap
→ Future<
bool?> Function(bool isLiked)? -
final
- outlineIcon → IconData
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → ReadyButtonSize
-
final
- solidIcon → IconData
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< ReadyLikeButton> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited