ReadyAvatar class

Inheritance

Constructors

ReadyAvatar({Key? key, String? name, String? imageUrl, double size = 60.0, bool? isOnline, bool isCircular = true, double borderRadius = 12.0, double? onlineIndicatorSize, Color? textColor, Color? backgroundColor})
const

Properties

backgroundColor Color?
Background color for initials placeholder (optional).
final
borderRadius double
Border radius (used when isCircular is false).
final
hashCode int
The hash code for this object.
no setterinherited
imageUrl String?
Image URL to load avatar image (optional).
final
initials String
Compute initials from name
no setter
isCircular bool
Use circular avatar or rectangular.
final
isOnline bool?
Show online indicator (null = hidden).
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
name String?
Name used to extract initials (optional).
final
onlineIndicatorSize double?
Size of online indicator (optional).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size double
Size of avatar (width and height).
final
textColor Color?
Text color for initials placeholder (optional).
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited