inputs/ready_inputs library
Classes
- CursorStyleData
- Custom class to handle cursor styling.
- ReadyInput
- A custom input widget with flexible configuration options.
- ReadyPhoneInput
- A customizable phone input widget with country code selector.
Enums
- InputDecorationType
- Enum to define the type of decoration for the input field.