ReadyInput class
A custom input widget with flexible configuration options.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- ReadyInput
Constructors
-
ReadyInput({Key? key, Widget? prefixIcon, String? label, bool showLabelInside = true, String? hint, bool isObscure = false, AutovalidateMode? autovalidateMode, TextInputType textInputType = TextInputType.text, TextInputAction textInputAction = TextInputAction.done, TextEditingController? controller, String? validator(String?)?, bool enabled = true, bool autoFocus = false, int minLines = 1, int? maxLines, bool readOnly = false, dynamic onTap()?, dynamic onChanged(String)?, Widget? suffixIcon, int? maxLength, List<
TextInputFormatter> ? inputFormatters, InputDecorationType decorationType = InputDecorationType.outlined, FocusNode? focusNode, void onFieldSubmitted(String)?, TextCapitalization textCapitalization = TextCapitalization.none, TextAlign textAlign = TextAlign.start, TextAlignVertical? textAlignVertical, TextStyle? style, CursorStyleData? cursorStyle, bool enableSuggestions = true, bool enableInteractiveSelection = true, Widget? buildCounter(BuildContext, {int currentLength, bool isFocused, int? maxLength})?, bool expands = false, VoidCallback? onEditingComplete, EdgeInsets scrollPadding = const EdgeInsets.all(20.0), BorderRadius? borderRadius}) -
const
Properties
- autoFocus → bool
-
final
- autovalidateMode → AutovalidateMode?
-
final
- borderRadius → BorderRadius?
-
final
- buildCounter → Widget? Function(BuildContext, {int currentLength, bool isFocused, int? maxLength})?
-
final
- controller → TextEditingController?
-
final
- cursorStyle → CursorStyleData?
-
final
- decorationType → InputDecorationType
-
final
- enabled → bool
-
final
- enableInteractiveSelection → bool
-
final
- enableSuggestions → bool
-
final
- expands → bool
-
final
- focusNode → FocusNode?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hint → String?
-
final
-
inputFormatters
→ List<
TextInputFormatter> ? -
final
- isObscure → bool
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- label → String?
-
final
- maxLength → int?
-
final
- maxLines → int?
-
final
- minLines → int
-
final
- onChanged → dynamic Function(String)?
-
final
- onEditingComplete → VoidCallback?
-
final
- onFieldSubmitted → void Function(String)?
-
final
- onTap → dynamic Function()?
-
final
- prefixIcon → Widget?
-
final
- readOnly → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scrollPadding → EdgeInsets
-
final
- showLabelInside → bool
-
final
- style → TextStyle?
-
final
- suffixIcon → Widget?
-
final
- textAlign → TextAlign
-
final
- textAlignVertical → TextAlignVertical?
-
final
- textCapitalization → TextCapitalization
-
final
- textInputAction → TextInputAction
-
final
- textInputType → TextInputType
-
final
- validator → String? Function(String?)?
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< ReadyInput> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited