ReadyReadMoreText class

A widget that trims long text and shows "Read more"/"Read less" links.

Inheritance

Constructors

ReadyReadMoreText({Key? key, required String text, TextStyle? textStyle, TextStyle? moreLessStyle, int trimLines = 2, int trimLength = 100, TrimMode trimMode = TrimMode.line, String readMoreText = ' Read more', String readLessText = ' Read less'})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
moreLessStyle TextStyle?
Style for the "Read more"/"Read less" links.
final
readLessText String
Text shown to collapse the content.
final
readMoreText String
Text shown to expand the content.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
final
textStyle TextStyle?
Style for the main text.
final
trimLength int
Number of characters to trim to when trimMode is TrimMode.length.
final
trimLines int
Number of lines to trim to when trimMode is TrimMode.line.
final
trimMode TrimMode
Whether trimming is based on line count or text length.
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<ReadyReadMoreText>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited